|PyPI| |Docs| |PePy|

.. |PyPI| image:: https://img.shields.io/pypi/v/novosparc.svg
   :target: https://pypi.org/project/novosparc/
.. |Docs| image:: https://readthedocs.org/projects/novosparc/badge/?version=latest
   :target: https://novosparc.readthedocs.io/
.. |PePy| image:: https://static.pepy.tech/badge/novosparc
   :target: https://pepy.tech/project/novosparc

novoSpaRc - *de novo* Spatial Reconstruction of Single-Cell Gene Expression
===========================================================================

.. image:: https://raw.githubusercontent.com/nukappa/nukappa.github.io/master/images/novosparc.png
   :width: 90px
   :align: left

``novoSpaRc`` predicts locations of single cells in space by solely using 
single-cell RNA sequencing data. An existing reference database of marker genes
is not required, but significantly enhances performance if available.

``novoSpaRc`` accompanies the following publication:

    | *Gene Expression Cartography*
    | M. Nitzan, N. Karaiskos, N. Friedman, N. Rajewsky
    | `Nature (2019) <https://www.nature.com/articles/s41586-019-1773-3>`_

Read the `documentation <https://novosparc.readthedocs.io>`_ and the 
`tutorial <https://github.com/rajewsky-lab/novosparc/blob/master/reconstruct_drosophila_embryo_tutorial.ipynb>`_ for more information.
